@@ -7,6 +7,8 @@ from . import views
 import django_cloudspotlicense.views as auth_views
 
 urlpatterns = [
+    path('select-company', auth_views.SelectCompanyView.as_view(), name='select_company'),
+    path('set-company/<uuid:company_id>', auth_views.SetCompanyView.as_view(), name='set_company'),
     path('webhook', auth_views.WebhookView.as_view(), name='webhook'),
 ]
 
