@@ -4,7 +4,7 @@ from http import HTTPStatus
 from django.shortcuts import render, redirect
 from django.views import View
 from django.conf import settings
-from django.contrib.auth import login, get_user_model
+from django.contrib.auth import login, get_user_model, logout
 from django.core.exceptions import ObjectDoesNotExist
 from django.contrib.auth.models import Permission
 from django.contrib import messages
@@ -13,7 +13,6 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 from django.http import HttpResponseBadRequest, JsonResponse
 from django.contrib.auth.mixins import LoginRequiredMixin
-
 from cloudspotlicense.api import CloudspotLicense_API
 from cloudspotlicense.constants.errors import BadCredentials
 from cloudspotlicense.constants.responses import ResponseStatus
@@ -103,10 +102,10 @@ class LoginView(View):
                 # Assign all the returned permissions
                 permissions = []
                 for perm in api.permissions.items():
-                    if perm.company_id == user.company.id:
-                        
+                    if perm.company_id == str(user.company.id):
                         for perm in perm.permissions:
                             permissions.append(perm)
+                        break
                 
                 grant_permissions(user, permissions)
                 
@@ -197,7 +196,13 @@ class WebhookView(View):
             # Otherwise, these permissions do not apply to this user at this moment
             # When the user switches companies, the new permissions get retrieved from the License Server anyway
             if user.company == company:
-                revoke_permissions(user)
-                grant_permissions(user, permissions)
+                if 'use_app' not in permissions:
+                    # if the 'use_app' permission is revoked, the user is not allowed to use the app for this company anymore.
+                    # we set the company to none. This will force the user to choose a new company on next page load.
+                    user.company = None
+                    user.save()
+                else:
+                    revoke_permissions(user)
+                    grant_permissions(user, permissions)
 
             return JsonResponse({ 'status' : ResponseStatus.OBJECT_UPDATED })
\ No newline at end of file
